@@ -26,7 +26,7 @@
 from gen.layout import *
 from gen.float import *
 from ref.index import *
-from ref.biblio import *
+from bib.biblio import *
 from gen.basket import *
 
 
@@ -76,7 +76,7 @@ class IntegralBiblioEntry(IntegralProcessor):
 
   def processeach(self, entry):
     "Process each entry."
-    number = NumberGenerator.instance.generateunique('integralbib')
+    number = NumberGenerator.generator.generate('integralbib')
     link = Link().complete('cite', 'biblio-' + number, type='biblioentry')
     link.contents = entry.citeref
     entry.contents = [Constant('['), link, Constant('] ')]
@@ -116,7 +116,7 @@ class IntegralListOf(IntegralProcessor):
 
   def processfloat(self, float):
     "Get an entry for the list of floats."
-    if float.parentfloat:
+    if not float.isparent():
       return None
     return TOCEntry().create(float)
 
